using System;
using UnityEngine;
using System.IO;
using DaggerfallWorkshop.Game;
using DaggerfallWorkshop.Game.UserInterface;
using DaggerfallWorkshop.Game.UserInterfaceWindows;
using DaggerfallWorkshop.Utility.AssetInjection;

namespace BestiaryMod
{
    class BestiaryUI : DaggerfallPopupWindow
    {
        public bool isShowing = false;
        
        string backgroundTextureName = "base_background.png";
        string pictureTextureName = "picture_orc.png";
        string pathToEntry = "orc_entry.txt";


        #region UI Controls

        Texture2D backgroundTexture;
        Texture2D pictureTexture;

        Vector2 backgroundSizeVector;
        Vector2 picturebackgroundSizeVector;   
        Panel mainPanel;
        Panel imagePanel;

        TextLabel titleLable;
        TextLabel monsterNameLabel;
        TextLabel subTitleLable1;
        TextLabel subTitleLable2;
        TextLabel descriptionLable1;
        TextLabel descriptionLable2;
        TextLabel descriptionLable3;
        TextLabel descriptionLable4;
        TextLabel descriptionLable5;
        TextLabel descriptionLable6;
        TextLabel descriptionLable7;
        TextLabel descriptionLable8;
        TextLabel descriptionLable9;
        TextLabel descriptionLable10;
        TextLabel descriptionLable11;
        TextLabel descriptionLable12;
        TextLabel descriptionLable13;
        TextLabel descriptionLable14;

        Button exitButton;

        #endregion

        public BestiaryUI(IUserInterfaceManager uiManager)
            : base(uiManager)
        {
            pauseWhileOpened = true;
            AllowCancel = false;
        }

        protected override void Setup()
        {
            base.Setup();
            LoadTextures();

            backgroundSizeVector = new Vector2(320, 200);
            picturebackgroundSizeVector = new Vector2(106, 106);
            
            setUpUIElements();

            string[] entryText = File.ReadAllLines(pathToEntry);


            titleLable.Text = "Bestiary";

            monsterNameLabel.Text = "Orcs";
            subTitleLable1.Text = "Location";
            subTitleLable2.Text = "History";

            descriptionLable1.Text = "This is text label 1";
            descriptionLable2.Text = "And this is text label 2";
            descriptionLable3.Text = "This thing is text label 3";
            descriptionLable4.Text = "And this last one is text label 4";
            descriptionLable5.Text = "This is text label 5";
            descriptionLable6.Text = "And this is text label 6";
            descriptionLable7.Text = "This thing is text label 7";
            descriptionLable8.Text = "And this last one is text label 8";
            descriptionLable9.Text = "This is text label 9";
            descriptionLable10.Text = "And this is text label 10";
            descriptionLable11.Text = "This thing is text label 11";
            descriptionLable12.Text = "And this last one is text label 12";
            descriptionLable13.Text = "This thing is text label 13";
            descriptionLable14.Text = "And this last one is text label 14";
        }

        public override void Update()
        {
            base.Update();

            if (Input.GetKeyUp(exitKey))
                CloseWindow();
        }

        public override void OnPush()
        {
            base.OnPush();
            isShowing = true;
        }

        public override void OnPop()
        {
            base.OnPop();
            isShowing = false;
        }

        void LoadTextures()
        {
            backgroundTexture = DaggerfallUI.GetTextureFromResources(backgroundTextureName);
            if (!backgroundTexture)
                throw new Exception("BestiaryUI: Could not load background texture.");

            pictureTexture = DaggerfallUI.GetTextureFromResources(pictureTextureName);
            if (!pictureTexture)
                throw new Exception("BestiaryUI: Could not load pictureTexture.");
        }
        
        void setUpUIElements()
        {
            ParentPanel.BackgroundColor = ScreenDimColor;

            mainPanel = DaggerfallUI.AddPanel(NativePanel, AutoSizeModes.None);
            mainPanel.Size = backgroundSizeVector;
            mainPanel.BackgroundTexture = backgroundTexture;
            mainPanel.HorizontalAlignment = HorizontalAlignment.Center;
            mainPanel.VerticalAlignment = VerticalAlignment.Middle;

            imagePanel = DaggerfallUI.AddPanel(mainPanel, AutoSizeModes.None);
            imagePanel.Size = picturebackgroundSizeVector;
            imagePanel.BackgroundTexture = pictureTexture;
            imagePanel.Position = new Vector2(16, 49);

            titleLable = new TextLabel();
            titleLable.Position = new Vector2(16, 16);
            titleLable.Size = new Vector2(80, 16);
            titleLable.Name = "title_label";
            titleLable.Font = DaggerfallUI.TitleFont;
            mainPanel.Components.Add(titleLable);

            monsterNameLabel = new TextLabel();
            monsterNameLabel.Position = new Vector2(144, 20);
            monsterNameLabel.Size = new Vector2(40, 14);
            monsterNameLabel.Name = "sub_label_1";
            monsterNameLabel.Font = DaggerfallUI.LargeFont;
            mainPanel.Components.Add(monsterNameLabel);

            subTitleLable1 = new TextLabel();
            subTitleLable1.Position = new Vector2(144, 38);
            subTitleLable1.Size = new Vector2(40, 14);
            subTitleLable1.Name = "sub_label_2";
            subTitleLable1.Font = DaggerfallUI.LargeFont;
            mainPanel.Components.Add(subTitleLable1);

            subTitleLable2 = new TextLabel();
            subTitleLable2.Position = new Vector2(144, 80);
            subTitleLable2.Size = new Vector2(40, 14);
            subTitleLable2.Name = "sub_label_3";
            subTitleLable2.Font = DaggerfallUI.LargeFont;
            mainPanel.Components.Add(subTitleLable2);


            descriptionLable1 = new TextLabel();
            descriptionLable1.Position = new Vector2(188, 42);
            descriptionLable1.Size = new Vector2(120, 10);
            descriptionLable1.Name = "title_label_1";
            descriptionLable1.MaxCharacters = 40;
            mainPanel.Components.Add(descriptionLable1);

            descriptionLable2 = new TextLabel();
            descriptionLable2.Position = new Vector2(188, 52);
            descriptionLable2.Size = new Vector2(120, 10);
            descriptionLable2.Name = "title_label_2";
            descriptionLable2.MaxCharacters = 40;
            mainPanel.Components.Add(descriptionLable2);

            descriptionLable3 = new TextLabel();
            descriptionLable3.Position = new Vector2(188, 62);
            descriptionLable3.Size = new Vector2(120, 10);
            descriptionLable3.Name = "title_label_3";
            descriptionLable3.MaxCharacters = 40;
            mainPanel.Components.Add(descriptionLable3);

            descriptionLable4 = new TextLabel();
            descriptionLable4.Position = new Vector2(188, 72);
            descriptionLable4.Size = new Vector2(120, 10);
            descriptionLable4.Name = "title_label_4";
            descriptionLable4.MaxCharacters = 40;
            mainPanel.Components.Add(descriptionLable4);


            descriptionLable5 = new TextLabel();
            descriptionLable5.Position = new Vector2(188, 84);
            descriptionLable5.Size = new Vector2(120, 10);
            descriptionLable5.Name = "title_label_5";
            descriptionLable5.MaxCharacters = 40;
            mainPanel.Components.Add(descriptionLable5);

            descriptionLable6 = new TextLabel();
            descriptionLable6.Position = new Vector2(188, 94);
            descriptionLable6.Size = new Vector2(120, 10);
            descriptionLable6.Name = "title_label_6";
            descriptionLable6.MaxCharacters = 40;
            mainPanel.Components.Add(descriptionLable6);

            descriptionLable7 = new TextLabel();
            descriptionLable7.Position = new Vector2(188, 104);
            descriptionLable7.Size = new Vector2(120, 10);
            descriptionLable7.Name = "title_label_7";
            descriptionLable7.MaxCharacters = 40;
            mainPanel.Components.Add(descriptionLable7);

            descriptionLable8 = new TextLabel();
            descriptionLable8.Position = new Vector2(188, 114);
            descriptionLable8.Size = new Vector2(120, 10);
            descriptionLable8.Name = "title_label_8";
            descriptionLable8.MaxCharacters = 40;
            mainPanel.Components.Add(descriptionLable8);

            descriptionLable9 = new TextLabel();
            descriptionLable9.Position = new Vector2(188, 124);
            descriptionLable9.Size = new Vector2(120, 10);
            descriptionLable9.Name = "title_label_9";
            descriptionLable9.MaxCharacters = 40;
            mainPanel.Components.Add(descriptionLable9);

            descriptionLable10 = new TextLabel();
            descriptionLable10.Position = new Vector2(188, 134);
            descriptionLable10.Size = new Vector2(120, 10);
            descriptionLable10.Name = "title_label_10";
            descriptionLable10.MaxCharacters = 40;
            mainPanel.Components.Add(descriptionLable10);

            descriptionLable11 = new TextLabel();
            descriptionLable11.Position = new Vector2(188, 144);
            descriptionLable11.Size = new Vector2(120, 10);
            descriptionLable11.Name = "title_label_11";
            descriptionLable11.MaxCharacters = 40;
            mainPanel.Components.Add(descriptionLable11);

            descriptionLable12 = new TextLabel();
            descriptionLable12.Position = new Vector2(188, 154);
            descriptionLable12.Size = new Vector2(120, 10);
            descriptionLable12.Name = "title_label_12";
            descriptionLable12.MaxCharacters = 40;
            mainPanel.Components.Add(descriptionLable12);

            descriptionLable13 = new TextLabel();
            descriptionLable13.Position = new Vector2(188, 164);
            descriptionLable13.Size = new Vector2(120, 10);
            descriptionLable13.Name = "title_label_13";
            descriptionLable13.MaxCharacters = 40;
            mainPanel.Components.Add(descriptionLable13);

            descriptionLable14 = new TextLabel();
            descriptionLable14.Position = new Vector2(188, 174);
            descriptionLable14.Size = new Vector2(120, 10);
            descriptionLable14.Name = "title_label_14";
            descriptionLable14.MaxCharacters = 40;
            mainPanel.Components.Add(descriptionLable14);


            exitButton = new Button();
            exitButton.Position = new Vector2(216, 187);
            exitButton.Size = new Vector2(56, 25);
            exitButton.Name = "exit_button";
            exitButton.OnMouseClick += (_, __) => { CancelWindow(); };
            mainPanel.Components.Add(exitButton);
        }
    }
}